@@ -49,6 +49,18 @@ class Instance(
         '''
         jsii.create(self.__class__, self, [scope, id, props, enable_resource_property_constraint])
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="attrDomainEndpoint")
+    def attr_domain_endpoint(self) -> ros_cdk_core.IResolvable:
+        '''Attribute DomainEndpoint: The default endpoints of the instance in domain name mode.'''
+        return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrDomainEndpoint"))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="attrEndpoint")
+    def attr_endpoint(self) -> ros_cdk_core.IResolvable:
+        '''Attribute Endpoint: The SSL endpoints of the instance in IP address mode.'''
+        return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrEndpoint"))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="attrInstanceId")
     def attr_instance_id(self) -> ros_cdk_core.IResolvable:
@@ -67,6 +79,24 @@ class Instance(
         '''Attribute OrderId: Id of the order.'''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrOrderId"))
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="attrSaslDomainEndpoint")
+    def attr_sasl_domain_endpoint(self) -> ros_cdk_core.IResolvable:
+        '''Attribute SaslDomainEndpoint: The Simple Authentication and Security Layer (SASL) endpoints of the instance in domain name mode.'''
+        return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrSaslDomainEndpoint"))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="attrSslDomainEndpoint")
+    def attr_ssl_domain_endpoint(self) -> ros_cdk_core.IResolvable:
+        '''Attribute SslDomainEndpoint: The SSL endpoints of the instance in domain name mode.'''
+        return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrSslDomainEndpoint"))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="attrSslEndpoint")
+    def attr_ssl_endpoint(self) -> ros_cdk_core.IResolvable:
+        '''Attribute SslEndpoint: The SSL endpoints of the instance in IP address mode.'''
+        return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrSslEndpoint"))
+
 
 @jsii.data_type(
     jsii_type="@alicloud/ros-cdk-kafka.InstanceProps",
@@ -332,6 +362,22 @@ class RosInstance(
         '''The resource type name for this resource class.'''
         return typing.cast(builtins.str, jsii.sget(cls, "ROS_RESOURCE_TYPE_NAME"))
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="attrDomainEndpoint")
+    def attr_domain_endpoint(self) -> ros_cdk_core.IResolvable:
+        '''
+        :Attribute: DomainEndpoint: The default endpoints of the instance in domain name mode.
+        '''
+        return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrDomainEndpoint"))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="attrEndpoint")
+    def attr_endpoint(self) -> ros_cdk_core.IResolvable:
+        '''
+        :Attribute: Endpoint: The SSL endpoints of the instance in IP address mode.
+        '''
+        return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrEndpoint"))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="attrInstanceId")
     def attr_instance_id(self) -> ros_cdk_core.IResolvable:
@@ -356,6 +402,30 @@ class RosInstance(
         '''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrOrderId"))
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="attrSaslDomainEndpoint")
+    def attr_sasl_domain_endpoint(self) -> ros_cdk_core.IResolvable:
+        '''
+        :Attribute: SaslDomainEndpoint: The Simple Authentication and Security Layer (SASL) endpoints of the instance in domain name mode.
+        '''
+        return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrSaslDomainEndpoint"))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="attrSslDomainEndpoint")
+    def attr_ssl_domain_endpoint(self) -> ros_cdk_core.IResolvable:
+        '''
+        :Attribute: SslDomainEndpoint: The SSL endpoints of the instance in domain name mode.
+        '''
+        return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrSslDomainEndpoint"))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="attrSslEndpoint")
+    def attr_ssl_endpoint(self) -> ros_cdk_core.IResolvable:
+        '''
+        :Attribute: SslEndpoint: The SSL endpoints of the instance in IP address mode.
+        '''
+        return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrSslEndpoint"))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="rosProperties")
     def _ros_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
